@@ -26,12 +26,30 @@ FAILEDOPERATION_NOACTIVITYTOGENERATE = 'FailedOperation.NoActivityToGenerate'
 # An internal error occurred.
 INTERNALERROR = 'InternalError'
 
+# 
+INTERNALERROR_CALLCMQERROR = 'InternalError.CallCmqError'
+
+# 
+INTERNALERROR_CALLERROR = 'InternalError.CallError'
+
 # CLB API call failed.
 INTERNALERROR_CALLLBERROR = 'InternalError.CallLbError'
 
 # Monitor API call failed.
 INTERNALERROR_CALLMONITORERROR = 'InternalError.CallMonitorError'
 
+# 
+INTERNALERROR_CALLNOTIFICATIONERROR = 'InternalError.CallNotificationError'
+
+# 
+INTERNALERROR_CALLSTSERROR = 'InternalError.CallStsError'
+
+# 
+INTERNALERROR_CALLTAGERROR = 'InternalError.CallTagError'
+
+# 
+INTERNALERROR_CALLTVPCERROR = 'InternalError.CallTvpcError'
+
 # VPC API call failed.
 INTERNALERROR_CALLVPCERROR = 'InternalError.CallVpcError'
 
@@ -80,6 +98,9 @@ INVALIDPARAMETERCONFLICT = 'InvalidParameterConflict'
 # Wrong parameter value.
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 
+INVALIDPARAMETERVALUE_BASECAPACITYTOOLARGE = 'InvalidParameterValue.BaseCapacityTooLarge'
+
 # A classic CLB should be specified.
 INVALIDPARAMETERVALUE_CLASSICLB = 'InvalidParameterValue.ClassicLb'
 
@@ -110,6 +131,12 @@ INVALIDPARAMETERVALUE_FORWARDLB = 'InvalidParameterValue.ForwardLb'
 # The auto scaling group name already exists.
 INVALIDPARAMETERVALUE_GROUPNAMEDUPLICATED = 'InvalidParameterValue.GroupNameDuplicated'
 
+# 
+INVALIDPARAMETERVALUE_HOSTNAMEILLEGAL = 'InvalidParameterValue.HostNameIllegal'
+
+# 
+INVALIDPARAMETERVALUE_IMAGENOTFOUND = 'InvalidParameterValue.ImageNotFound'
+
 # Invalid instance name
 INVALIDPARAMETERVALUE_INSTANCENAMEILLEGAL = 'InvalidParameterValue.InstanceNameIllegal'
 
@@ -227,6 +254,9 @@ INVALIDPARAMETERVALUE_USERDATASIZEEXCEEDED = 'InvalidParameterValue.UserDataSize
 # The user group does not exist.
 INVALIDPARAMETERVALUE_USERGROUPIDNOTFOUND = 'InvalidParameterValue.UserGroupIdNotFound'
 
+# 
+INVALIDPARAMETERVALUE_ZONEMISMATCHREGION = 'InvalidParameterValue.ZoneMismatchRegion'
+
 # The account does not support this operation.
 INVALIDPERMISSION = 'InvalidPermission'
 
@@ -296,6 +326,9 @@ RESOURCENOTFOUND_AUTOSCALINGGROUPNOTFOUND = 'ResourceNotFound.AutoScalingGroupNo
 # The notification does not exist.
 RESOURCENOTFOUND_AUTOSCALINGNOTIFICATIONNOTFOUND = 'ResourceNotFound.AutoScalingNotificationNotFound'
 
+# 
+RESOURCENOTFOUND_CMQQUEUENOTFOUND = 'ResourceNotFound.CmqQueueNotFound'
+
 # The specified instance does not exist.
 RESOURCENOTFOUND_INSTANCESNOTFOUND = 'ResourceNotFound.InstancesNotFound'
 
@@ -335,6 +368,9 @@ RESOURCEUNAVAILABLE_AUTOSCALINGGROUPDISABLED = 'ResourceUnavailable.AutoScalingG
 # The auto scaling group is active.
 RESOURCEUNAVAILABLE_AUTOSCALINGGROUPINACTIVITY = 'ResourceUnavailable.AutoScalingGroupInActivity'
 
+# 
+RESOURCEUNAVAILABLE_CMQTOPICHASNOSUBSCRIBER = 'ResourceUnavailable.CmqTopicHasNoSubscriber'
+
 # The instance and the auto scaling group are in different VPCs.
 RESOURCEUNAVAILABLE_CVMVPCINCONSISTENT = 'ResourceUnavailable.CvmVpcInconsistent'
 
@@ -364,3 +400,6 @@ RESOURCEUNAVAILABLE_LOADBALANCERINOPERATION = 'ResourceUnavailable.LoadBalancerI
 
 # Project inconsistency.
 RESOURCEUNAVAILABLE_PROJECTINCONSISTENT = 'ResourceUnavailable.ProjectInconsistent'
+
+# 
+RESOURCEUNAVAILABLE_ZONEUNAVAILABLE = 'ResourceUnavailable.ZoneUnavailable'
