@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -35,6 +37,13 @@ class AlgorithmInfo(AbstractModel):
     def _deserialize(self, params):
         self.KeyUsage = params.get("KeyUsage")
         self.Algorithm = params.get("Algorithm")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ArchiveKeyRequest(AbstractModel):
@@ -52,6 +61,13 @@ class ArchiveKeyRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ArchiveKeyResponse(AbstractModel):
@@ -94,6 +110,13 @@ class AsymmetricRsaDecryptRequest(AbstractModel):
         self.KeyId = params.get("KeyId")
         self.Ciphertext = params.get("Ciphertext")
         self.Algorithm = params.get("Algorithm")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AsymmetricRsaDecryptResponse(AbstractModel):
@@ -140,6 +163,13 @@ class AsymmetricSm2DecryptRequest(AbstractModel):
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
         self.Ciphertext = params.get("Ciphertext")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AsymmetricSm2DecryptResponse(AbstractModel):
@@ -190,6 +220,13 @@ class BindCloudResourceRequest(AbstractModel):
         self.KeyId = params.get("KeyId")
         self.ProductId = params.get("ProductId")
         self.ResourceId = params.get("ResourceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class BindCloudResourceResponse(AbstractModel):
@@ -224,6 +261,13 @@ class CancelKeyArchiveRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CancelKeyArchiveResponse(AbstractModel):
@@ -258,6 +302,13 @@ class CancelKeyDeletionRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CancelKeyDeletionResponse(AbstractModel):
@@ -317,6 +368,13 @@ class CreateKeyRequest(AbstractModel):
                 obj = Tag()
                 obj._deserialize(item)
                 self.Tags.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateKeyResponse(AbstractModel):
@@ -400,6 +458,13 @@ class CreateWhiteBoxKeyRequest(AbstractModel):
                 obj = Tag()
                 obj._deserialize(item)
                 self.Tags.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateWhiteBoxKeyResponse(AbstractModel):
@@ -458,6 +523,13 @@ class DecryptRequest(AbstractModel):
     def _deserialize(self, params):
         self.CiphertextBlob = params.get("CiphertextBlob")
         self.EncryptionContext = params.get("EncryptionContext")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DecryptResponse(AbstractModel):
@@ -500,6 +572,13 @@ class DeleteImportedKeyMaterialRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteImportedKeyMaterialResponse(AbstractModel):
@@ -534,6 +613,13 @@ class DeleteWhiteBoxKeyRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteWhiteBoxKeyResponse(AbstractModel):
@@ -568,6 +654,13 @@ class DescribeKeyRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeKeyResponse(AbstractModel):
@@ -609,6 +702,13 @@ class DescribeKeysRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyIds = params.get("KeyIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeKeysResponse(AbstractModel):
@@ -653,6 +753,13 @@ class DescribeWhiteBoxDecryptKeyRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeWhiteBoxDecryptKeyResponse(AbstractModel):
@@ -691,6 +798,13 @@ class DescribeWhiteBoxDeviceFingerprintsRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeWhiteBoxDeviceFingerprintsResponse(AbstractModel):
@@ -751,6 +865,13 @@ class DescribeWhiteBoxKeyDetailsRequest(AbstractModel):
                 obj = TagFilter()
                 obj._deserialize(item)
                 self.TagFilters.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeWhiteBoxKeyDetailsResponse(AbstractModel):
@@ -799,6 +920,13 @@ class DescribeWhiteBoxKeyRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeWhiteBoxKeyResponse(AbstractModel):
@@ -871,6 +999,13 @@ Note: this field may return null, indicating that no valid values can be obtaine
     def _deserialize(self, params):
         self.Identity = params.get("Identity")
         self.Description = params.get("Description")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DisableKeyRequest(AbstractModel):
@@ -888,6 +1023,13 @@ class DisableKeyRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DisableKeyResponse(AbstractModel):
@@ -922,6 +1064,13 @@ class DisableKeyRotationRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DisableKeyRotationResponse(AbstractModel):
@@ -956,6 +1105,13 @@ class DisableKeysRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyIds = params.get("KeyIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DisableKeysResponse(AbstractModel):
@@ -990,6 +1146,13 @@ class DisableWhiteBoxKeyRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DisableWhiteBoxKeyResponse(AbstractModel):
@@ -1024,6 +1187,13 @@ class DisableWhiteBoxKeysRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyIds = params.get("KeyIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DisableWhiteBoxKeysResponse(AbstractModel):
@@ -1058,6 +1228,13 @@ class EnableKeyRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EnableKeyResponse(AbstractModel):
@@ -1092,6 +1269,13 @@ class EnableKeyRotationRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EnableKeyRotationResponse(AbstractModel):
@@ -1126,6 +1310,13 @@ class EnableKeysRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyIds = params.get("KeyIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EnableKeysResponse(AbstractModel):
@@ -1160,6 +1351,13 @@ class EnableWhiteBoxKeyRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EnableWhiteBoxKeyResponse(AbstractModel):
@@ -1194,6 +1392,13 @@ class EnableWhiteBoxKeysRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyIds = params.get("KeyIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EnableWhiteBoxKeysResponse(AbstractModel):
@@ -1236,6 +1441,13 @@ class EncryptByWhiteBoxRequest(AbstractModel):
         self.KeyId = params.get("KeyId")
         self.PlainText = params.get("PlainText")
         self.InitializationVector = params.get("InitializationVector")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EncryptByWhiteBoxResponse(AbstractModel):
@@ -1286,6 +1498,13 @@ class EncryptRequest(AbstractModel):
         self.KeyId = params.get("KeyId")
         self.Plaintext = params.get("Plaintext")
         self.EncryptionContext = params.get("EncryptionContext")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EncryptResponse(AbstractModel):
@@ -1340,6 +1559,13 @@ class GenerateDataKeyRequest(AbstractModel):
         self.KeySpec = params.get("KeySpec")
         self.NumberOfBytes = params.get("NumberOfBytes")
         self.EncryptionContext = params.get("EncryptionContext")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GenerateDataKeyResponse(AbstractModel):
@@ -1386,6 +1612,13 @@ class GenerateRandomRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.NumberOfBytes = params.get("NumberOfBytes")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GenerateRandomResponse(AbstractModel):
@@ -1424,6 +1657,13 @@ class GetKeyRotationStatusRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetKeyRotationStatusResponse(AbstractModel):
@@ -1470,6 +1710,13 @@ class GetParametersForImportRequest(AbstractModel):
         self.KeyId = params.get("KeyId")
         self.WrappingAlgorithm = params.get("WrappingAlgorithm")
         self.WrappingKeySpec = params.get("WrappingKeySpec")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetParametersForImportResponse(AbstractModel):
@@ -1520,6 +1767,13 @@ class GetPublicKeyRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetPublicKeyResponse(AbstractModel):
@@ -1656,6 +1910,13 @@ class ImportKeyMaterialRequest(AbstractModel):
         self.ImportToken = params.get("ImportToken")
         self.KeyId = params.get("KeyId")
         self.ValidTo = params.get("ValidTo")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImportKeyMaterialResponse(AbstractModel):
@@ -1690,6 +1951,13 @@ class Key(AbstractModel):
 
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class KeyMetadata(AbstractModel):
@@ -1765,6 +2033,13 @@ Note: This field may return null, indicating that no valid values can be obtaine
         self.Origin = params.get("Origin")
         self.ValidTo = params.get("ValidTo")
         self.ResourceId = params.get("ResourceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ListAlgorithmsRequest(AbstractModel):
@@ -1869,6 +2144,13 @@ class ListKeyDetailRequest(AbstractModel):
                 obj = TagFilter()
                 obj._deserialize(item)
                 self.TagFilters.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ListKeyDetailResponse(AbstractModel):
@@ -1925,6 +2207,13 @@ class ListKeysRequest(AbstractModel):
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
         self.Role = params.get("Role")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ListKeysResponse(AbstractModel):
@@ -1981,6 +2270,13 @@ class OverwriteWhiteBoxDeviceFingerprintsRequest(AbstractModel):
                 obj = DeviceFingerprint()
                 obj._deserialize(item)
                 self.DeviceFingerprints.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OverwriteWhiteBoxDeviceFingerprintsResponse(AbstractModel):
@@ -2027,6 +2323,13 @@ class ReEncryptRequest(AbstractModel):
         self.DestinationKeyId = params.get("DestinationKeyId")
         self.SourceEncryptionContext = params.get("SourceEncryptionContext")
         self.DestinationEncryptionContext = params.get("DestinationEncryptionContext")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ReEncryptResponse(AbstractModel):
@@ -2081,6 +2384,13 @@ class ScheduleKeyDeletionRequest(AbstractModel):
     def _deserialize(self, params):
         self.KeyId = params.get("KeyId")
         self.PendingWindowInDays = params.get("PendingWindowInDays")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ScheduleKeyDeletionResponse(AbstractModel):
@@ -2135,6 +2445,13 @@ class SignByAsymmetricKeyRequest(AbstractModel):
         self.Message = params.get("Message")
         self.KeyId = params.get("KeyId")
         self.MessageType = params.get("MessageType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SignByAsymmetricKeyResponse(AbstractModel):
@@ -2177,6 +2494,13 @@ class Tag(AbstractModel):
     def _deserialize(self, params):
         self.TagKey = params.get("TagKey")
         self.TagValue = params.get("TagValue")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TagFilter(AbstractModel):
@@ -2198,6 +2522,13 @@ class TagFilter(AbstractModel):
     def _deserialize(self, params):
         self.TagKey = params.get("TagKey")
         self.TagValue = params.get("TagValue")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UnbindCloudResourceRequest(AbstractModel):
@@ -2223,6 +2554,13 @@ class UnbindCloudResourceRequest(AbstractModel):
         self.KeyId = params.get("KeyId")
         self.ProductId = params.get("ProductId")
         self.ResourceId = params.get("ResourceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UnbindCloudResourceResponse(AbstractModel):
@@ -2261,6 +2599,13 @@ class UpdateAliasRequest(AbstractModel):
     def _deserialize(self, params):
         self.Alias = params.get("Alias")
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateAliasResponse(AbstractModel):
@@ -2299,6 +2644,13 @@ class UpdateKeyDescriptionRequest(AbstractModel):
     def _deserialize(self, params):
         self.Description = params.get("Description")
         self.KeyId = params.get("KeyId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateKeyDescriptionResponse(AbstractModel):
@@ -2349,6 +2701,13 @@ class VerifyByAsymmetricKeyRequest(AbstractModel):
         self.Message = params.get("Message")
         self.Algorithm = params.get("Algorithm")
         self.MessageType = params.get("MessageType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class VerifyByAsymmetricKeyResponse(AbstractModel):
@@ -2431,4 +2790,11 @@ Note: this field may return null, indicating that no valid values can be obtaine
         self.EncryptKey = params.get("EncryptKey")
         self.DecryptKey = params.get("DecryptKey")
         self.ResourceId = params.get("ResourceId")
-        self.DeviceFingerprintBind = params.get("DeviceFingerprintBind")
\ No newline at end of file
+        self.DeviceFingerprintBind = params.get("DeviceFingerprintBind")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
