@@ -1230,6 +1230,34 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def KillMasterGroup(self, request):
+        """This API is used to perform a failure simulation.
+
+        :param request: Request instance for KillMasterGroup.
+        :type request: :class:`tencentcloud.redis.v20180412.models.KillMasterGroupRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.KillMasterGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("KillMasterGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.KillMasterGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ManualBackupInstance(self, request):
         """This API is used to manually back up a Redis instance.
 
