@@ -56,9 +56,6 @@ INVALIDINSTANCEID_ALREADYBINDEIP = 'InvalidInstanceId.AlreadyBindEip'
 # Invalid instance ID. The specified instance ID does not exist.
 INVALIDINSTANCEID_NOTFOUND = 'InvalidInstanceId.NotFound'
 
-# The specified NetworkInterfaceId does not exist or the specified PrivateIpAddress is not on the NetworkInterfaceId.
-INVALIDNETWORKINTERFACEID_NOTFOUND = 'InvalidNetworkInterfaceId.NotFound'
-
 # A parameter error occurred.
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -146,9 +143,6 @@ INVALIDPARAMETERVALUE_VPNCONNCIDRCONFLICT = 'InvalidParameterValue.VpnConnCidrCo
 # The `Zone` parameter value should be the zone where CDC resides.
 INVALIDPARAMETERVALUE_ZONECONFLICT = 'InvalidParameterValue.ZoneConflict'
 
-# The specified private IP of the specified ENI has already been bound to an EIP. A private IP cannot be bound to more than one EIP.
-INVALIDPRIVATEIPADDRESS_ALREADYBINDEIP = 'InvalidPrivateIpAddress.AlreadyBindEip'
-
 # Invalid routing policy ID (RouteId).
 INVALIDROUTEID_NOTFOUND = 'InvalidRouteId.NotFound'
 
@@ -206,9 +200,6 @@ LIMITEXCEEDED_SUBNETCIDRBLOCK = 'LimitExceeded.SubnetCidrBlock'
 # Missing parameter.
 MISSINGPARAMETER = 'MissingParameter'
 
-# The entity to be bound to is missing. InstanceId, NetworkInterfaceId or PrivateIpAddress must be specified.
-MISSINGRESOURCEID = 'MissingResourceId'
-
 # The resource is occupied.
 RESOURCEINUSE = 'ResourceInUse'
 
